@@ -47,7 +47,7 @@ Clazz.defineMethod (c$, "isStereo",
 function () {
 return (this.order & 1024) != 0;
 });
-Clazz.defineMethod (c$, "isPartial", 
+Clazz.overrideMethod (c$, "isPartial", 
 function () {
 return (this.order & 224) != 0;
 });
@@ -61,7 +61,7 @@ return 0;
 });
 Clazz.defineMethod (c$, "getValence", 
 function () {
-return (!this.isCovalent () ? 0 : this.isPartial () || this.is (515) ? 1 : this.order & 7);
+return (!this.isCovalent () || this.order == 33 ? 0 : this.is (515) ? 1 : this.order & 7);
 });
 Clazz.defineMethod (c$, "deleteAtomReferences", 
 function () {
@@ -135,5 +135,9 @@ Clazz.overrideMethod (c$, "getAtom",
 function (i) {
 return (i == 1 ? this.atom2 : this.atom1);
 }, "~N");
+Clazz.defineMethod (c$, "isCovalentNotPartial0", 
+function () {
+return ((this.order & 1023) != 0 && this.order != 33);
+});
 c$.myVisibilityFlag = c$.prototype.myVisibilityFlag = JV.JC.getShapeVisibilityFlag (1);
 });
