@@ -467,9 +467,8 @@ var sb =  new JU.SB ();
 sb.appendI (pts.length).append ("\n").append ("Viewer.AddHydrogens").append ("#noautobond").append ("\n");
 for (var i = 0; i < pts.length; i++) sb.append ("H ").appendF (pts[i].x).append (" ").appendF (pts[i].y).append (" ").appendF (pts[i].z).append (" - - - - ").appendI (++atomno).appendC ('\n');
 
-System.out.println ("SM " + sb + " " + sbConnect);
 this.vwr.openStringInlineParamsAppend (sb.toString (), htParams, true);
-this.vwr.runScript (sbConnect.toString ());
+if (sbConnect.length () > 0) this.vwr.runScript (sbConnect.toString ());
 var bsB = this.vwr.getModelUndeletedAtomsBitSet (modelIndex);
 bsB.andNot (bsA);
 this.vwr.g.appendNew = wasAppendNew;
