@@ -189,6 +189,10 @@ Clazz.overrideMethod (c$, "isCovalent",
 function () {
 return this.order != 112;
 });
+Clazz.overrideMethod (c$, "isPartial", 
+function () {
+return false;
+});
 Clazz.overrideMethod (c$, "isHydrogen", 
 function () {
 return this.order == 112;
