@@ -307,7 +307,7 @@ function (search, v) {
 this.v = v;
 this.search = search;
 this.jmolAtoms = search.targetAtoms;
-var haveTopo = search.haveTopo;
+var haveTopo = search.haveSmilesTarget;
 var invertStereochemistry = search.invertStereochemistry;
 if (JU.Logger.debugging) JU.Logger.debug ("checking stereochemistry...");
 for (var i = 0; i < search.ac; i++) {
