@@ -616,7 +616,7 @@ cpts.addLast (pt);
 }
 }
 }
-for (var i = n; --i >= 0; ) cpts.removeItemAt (i);
+for (var i = n; --i >= 0; ) cpts.removeItemAt (0);
 
 return cpts;
 }, "JU.Lst,~N,~N,~N");
