@@ -42,34 +42,34 @@ y;y=q.nextSetBit(y+1),c++)D[B][c]=A[w].distance(A[y])}return d.addXAFF(D)}if(k){
 d.ptValue(f,null),E=this.e.planeValue(f);e?a=null!=l&&null!=g?JU.Measure.directedDistanceToPlane(P,l,JS.SV.ptValue(g)):null==E?null==l?j.distance(P):JU.Measure.distanceToPlane(l,P):JU.Measure.distanceToPlane(E,j):null!=E&&null!=l?a=E.x*l.x+E.y*l.y+E.z*l.z+E.w*l.w:(null!=E?P=JU.P3.new3(E.x,E.y,E.z):null!=l&&(j=JU.P3.new3(l.x,l.y,l.z)),a=P.dot(j))}catch(K){if(!L(K,Exception))throw K;}return d.addXFloat(a)},"JS.ScriptMathProcessor,~A,~N,~N");q(c$,"evaluateHelix",function(d,a){if(1>a.length||5<a.length)return!1;
 var b=2<a.length?3:1,c=b>=a.length?"array":JS.SV.sValue(a[b]),b=JS.T.getTokFromName(c);if(2<a.length){var e=d.ptValue(a[0],null),f=d.ptValue(a[1],null);if(0==b||9!=a[2].tok||null==e||null==f)return!1;var h=JU.Quat.newP4(a[2].value),h=JU.Measure.computeHelicalAxis(e,f,h);return null==h?!1:d.addXObj(JU.Escape.escapeHelical(c,b,e,f,h))}c=z(a[0].value,JU.BS)?a[0].value:this.vwr.ms.getAtoms(1094715412,new Integer(a[0].asInt()));switch(b){case 134217751:case 1073741854:case 1665140738:return d.addXObj(this.getHelixData(c,
 b));case 134217729:return d.addXFloat(this.getHelixData(c,134217729).floatValue());case 135176:case 1745489939:return d.addXObj(this.getHelixData(c,b));case 1275068418:h=this.getHelixData(c,1073742001);if(null==h)break;return d.addXAS(h)}return!1},"JS.ScriptMathProcessor,~A");q(c$,"getHelixData",function(d,a){var b=d.nextSetBit(0);return 0>b?"null":this.vwr.ms.at[b].group.getHelixData(a,this.vwr.getQuaternionFrame(),this.vwr.getInt(553648142))},"JU.BS,~N");q(c$,"evaluateInChI",function(d,a){var b=
-d.getX(),c=0<a.length?JS.SV.sValue(a[0]):"fixedh?";c.toLowerCase().equals("standard")&&(c="");var e=JS.SV.getBitSet(b,!0),f=null;null==e&&(f=JS.SV.sValue(b));return d.addXStr(this.vwr.getInchi(e,f,c))},"JS.ScriptMathProcessor,~A");q(c$,"evaluateFind",function(d,a){var b=d.getX(),c=7==b.tok,e=10==b.tok,f=0==a.length,h=0==a.length?0:a[0].tok,g=f||4!=h?"":JS.SV.sValue(a[0]),k=1<a.length&&1073742334==a[1].tok,j=0==h?0:a[a.length-1].tok,l=0==j?JS.SV.vF:a[a.length-1],r=!c&&1073742335==j,m=1<a.length&&1073742335!=
+d.getX(),c=0<a.length?JS.SV.sValue(a[0]):"fixedh?";c.toLowerCase().equals("standard")&&(c="");var e=JS.SV.getBitSet(b,!0),b=null==e?JS.SV.sValue(b):null;return d.addXStr(this.vwr.getInchi(e,b,c))},"JS.ScriptMathProcessor,~A");q(c$,"evaluateFind",function(d,a){var b=d.getX(),c=7==b.tok,e=10==b.tok,f=0==a.length,h=0==a.length?0:a[0].tok,g=f||4!=h?"":JS.SV.sValue(a[0]),k=1<a.length&&1073742334==a[1].tok,j=0==h?0:a[a.length-1].tok,l=0==j?JS.SV.vF:a[a.length-1],r=!c&&1073742335==j,m=1<a.length&&1073742335!=
 a[1].tok&&1073742334!=a[1].tok&&10!=a[1].tok?JS.SV.sValue(a[1]):"",j=!c&&!k&&g.equalsIgnoreCase("SEQUENCE"),t=!c&&!k&&g.equalsIgnoreCase("SEQ");if(g.toUpperCase().startsWith("SMILES/")){g.endsWith("/")||(g+="/");var n=g.substring(6)+"//";JV.JC.isSmilesCanonical(n)?(m="SMILES",g="CHEMICAL"):(g="SMILES",m=n+m)}else g.toUpperCase().startsWith("SMARTS/")&&(g.endsWith("/")||(g+="/"),m=g.substring(6)+(0==m.length?"//":m),g="SMARTS");var p=null,n=!1;if(4==b.tok)switch(a.length){case 1:if(b.value.startsWith("InChI=")&&
-g.equalsIgnoreCase("SMILES"))return d.addXStr(this.vwr.getInchi(null,b.value,"SMILES"+m));n=!0;break;case 2:k||r?n=!0:b.value.startsWith("InChI=")?g.equals("SMARTS")?p=this.vwr.getInchi(null,b.value,"SMILES"):n=!0:3>=m.length&&0==m.$replace("m"," ").$replace("i"," ").$replace("v"," ").trim().length&&(n=!0)}var q=!c&&!n&&g.equalsIgnoreCase("SMILES"),u=!c&&!n&&g.equalsIgnoreCase("SMARTS"),z=!c&&!n&&g.equalsIgnoreCase("CHEMICAL"),x=!c&&!n&&g.equalsIgnoreCase("MF"),A=!c&&!n&&g.equalsIgnoreCase("CELLFORMULA"),
-B=e&&!c&&g.equalsIgnoreCase("INCHI"),D=e&&!c&&g.equalsIgnoreCase("INCHIKEY"),w=!q&&!u&&10==h&&0<=m.toLowerCase().indexOf("map"),n=(10==b.tok||8==b.tok||7==b.tok)&&g.toLowerCase().startsWith("equivalent");try{if(n)switch(b.tok){case 10:return d.addXBs(this.vwr.ms.getSymmetryEquivAtoms(b.value));case 8:return d.addXList(this.vwr.getSymmetryEquivPoints(b.value,g+m));case 7:for(var F=new JU.Lst,V=b.getList(),s=0,y=V.size();s<y;s++){var P=JS.SV.ptValue(V.get(s));if(null==P)return!1;F.addLast(P)}return d.addXList(this.vwr.getSymmetryEquivPointList(F,
-g+m))}else if(B||D)return D&&(m+=" key"),d.addXStr(this.vwr.getInchi(JS.SV.getBitSet(b,!0),null,m));if(z){var E=e?b.value:null,K=null==E?JS.SV.sValue(b):this.vwr.getOpenSmiles(E),K=(0==K.length?"":this.vwr.getChemicalInfo(K,m.toLowerCase(),E)).trim();K.startsWith("InChI")&&(K=JU.PT.rep(JU.PT.rep(K,"InChI=",""),"InChIKey=",""));return d.addXStr(K)}if(q||u||e){var e=w?0:q||u?2:1,G=e<a.length&&10==a[e].tok?a[e++].value:null,U="bonds".equalsIgnoreCase(JS.SV.sValue(l)),F=U||r,e=null;switch(b.tok){case 4:null==
-p&&(p=JS.SV.sValue(b));if((q||u)&&1==a.length||null!=G)return!1;if(m.equalsIgnoreCase("mf"))e=this.vwr.getSmilesMatcher().getMolecularFormula(p,u,r);else{var G=m,v=!0,s=!1;switch(a.length){case 4:v=JS.SV.bValue(a[3]);case 3:s=JS.SV.bValue(a[2])}var Q=G.equals("chirality"),y=!s&&(!v||!u&&!Q);try{e=this.e.getSmilesExt().getSmilesMatches(G,p,null,null,u?2:1,!s,!v)}catch(W){if(L(W,Exception))return System.out.println(W.getMessage()),d.addXInt(-1);throw W;}var M=Q?1:(JU.AU.isAI(e),e.length);0==M&&("MF_FAILED"!==
-this.vwr.getSmilesMatcher().getLastException()&&0>p.toLowerCase().indexOf("noaromatic")&&0>p.toLowerCase().indexOf("strict"))&&(e=this.e.getSmilesExt().getSmilesMatches(G,p,null,null,16|(u?2:1),!s,!v));if(y)return d.addXInt(!v&&0<M?1:M)}break;case 10:v=b.value;if(g.equalsIgnoreCase("spacegroup"))return d.addXObj(this.vwr.findSpaceGroup(v,null,null,!1,!1));if(g.equalsIgnoreCase("crystalClass"))return y=v.nextSetBit(0),v=null,2!=a.length&&(v=new JU.BS,v.set(y)),d.addXList(this.vwr.ms.generateCrystalClass(y,
-null!=v?this.vwr.ms.getAtomSetCenter(v):10==l.tok?this.vwr.ms.getAtomSetCenter(l.value):JS.SV.ptValue(l)));if(x&&0!=m.length)return d.addXBs(JU.JmolMolecule.getBitSetForMF(this.vwr.ms.at,v,m));if(x||A)return d.addXStr(this.vwr.getFormulaForAtoms(v,x?"MF":"CELLFORMULA",r));if(j||t){var Y=l.asString().equalsIgnoreCase("H"),F=(new Boolean(F|Y)).valueOf();return d.addXStr(this.vwr.getSmilesOpt(v,-1,-1,(F?7340032|(Y?9437184:0):0)|(t?34603008:1048576),null))}if(w){var H=null,M=Q=y=null,N=3==a.length?JS.SV.sValue(l):
-null,R=null==N||N.equals("%i")||N.equals("number")?"i":N.equals("%a")||N.equals("name")?"a":N.equals("%D")||N.equals("index")?"D":"?";null==N&&(N="number");l=null;m=m.$replace("map","").trim();g=this.vwr.getSmilesOpt(v,0,0,0,m);if(v.cardinality()!=G.cardinality())l="atom sets are not the same size";else try{0<m.length&&(g="/"+m+"/"+g);var y=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,v,137)[0],X=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,
-G,137);if(0<X.length){H=O(v.length(),0);for(s=H.length;0<=--s;)H[s]=-1;Q=X[0];for(s=y.length;0<=--s;)H[y[s]]=Q[s];var M=C(y.length,2,null),ca=JU.BS.copy(v);ca.or(G);var S="?"==R?Array(ca.length()):null;null!=S&&(S=this.e.getCmdExt().getBitsetIdentFull(ca,N,null,!1,2147483647,!1,S));for(var I=this.vwr.ms.at,X=0,s=v.nextSetBit(0);0<=s;s=v.nextSetBit(s+1)){var aa=H[s];if(-1!=aa){var ba;switch(R){case "a":ba=C(-1,[I[s].getAtomName(),I[aa].getAtomName()]);break;case "i":ba=C(-1,[Integer.$valueOf(I[s].getAtomNumber()),
-Integer.$valueOf(I[aa].getAtomNumber())]);break;case "D":ba=C(-1,[Integer.$valueOf(s),Integer.$valueOf(aa)]);break;default:ba=C(-1,[S[s],S[aa]])}M[X++]=ba}}}}catch(da){if(L(da,Exception))l=da.getMessage();else throw da;}var T=new java.util.HashMap;T.put("BS1",v);T.put("BS2",G);T.put("SMILES",g);null==l?(T.put("SMILEStoBS1",y),T.put("SMILEStoBS2",Q),T.put("BS1toBS2",H),T.put("MAP1to2",M),T.put("key",N)):T.put("error",l);return d.addXMap(T)}if(q||u)g=1<a.length&&10==a[1].tok?this.vwr.getSmilesOpt(a[1].value,
-0,0,0,m):m;m=m.toUpperCase();if(0<=m.indexOf("INCHI"))return d.addXStr(this.vwr.getInchi(v,null,"SMILES/"+m));if(m.equals("MF"))p=this.e.getSmilesExt().getSmilesMatches("",null,v,G,1,!0,!1),e=this.vwr.getSmilesMatcher().getMolecularFormula(p,!1,r);else if(U)H=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,v,(q?1:2)|8),e=0<H.length?this.vwr.ms.getDihedralMap(H[0]):O(0,0);else if(m.equals("MAP"))e=H=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,
-v,(q?1:2)|144);else{var Z=(q?0<=m.indexOf("OPEN")?5:1:2)|(r&&0==g.length?22020096:0);if(0<=m.indexOf("/MOLECULE/")){for(var ea=this.vwr.ms.getMolecules(),$=new JU.Lst,s=0;s<ea.length;s++)if(ea[s].atomList.intersects(v)){var ha=this.e.getSmilesExt().getSmilesMatches(g,null,ea[s].atomList,G,Z,!r,!1);ha.isEmpty()||$.addLast(ha)}e=$}else e=this.e.getSmilesExt().getSmilesMatches(g,null,v,G,Z,!r,!1)}}null==e&&this.e.invArg();return d.addXObj(e)}}catch(fa){if(L(fa,Exception))this.e.evalError(fa.getMessage(),
-null);else throw fa;}v=new JU.BS;H=c?b.getList():null;if(c&&4!=h&&0!=h){b=a[0];s=0;for(y=H.size();s<y;s++)JS.SV.areEqual(H.get(s),b)&&v.set(s);e=O(v.cardinality(),0);X=0;for(s=v.nextSetBit(0);0<=s;s=v.nextSetBit(s+1))e[X++]=s+1;return d.addXAI(e)}h=0<=m.indexOf("v");s=0<=m.indexOf("i")||k;k=0<=m.indexOf("m");m=0==g.length;n=!m&&!n&&2==a.length;if(c||n){j=n?this.getPatternMatcher():null;G=null;if(n)try{G=j.compile(g,s)}catch(ga){if(L(ga,Exception))this.e.evalError(ga.toString(),null);else throw ga;
-}j=m?null:JS.SV.strListValue(b);N=m?H.size():j.length;JU.Logger.debugging&&JU.Logger.debug("finding "+g);y=0;R=null;b=k?new JU.Lst:null;S="";for(s=0;s<N;s++){if(m)switch(I=H.get(s),I.tok){case 6:I=I.getMap().isEmpty()!=f;break;case 7:I=0==I.getList().size()!=f;break;case 4:I=0==I.asString().length!=f;break;default:I=!0}else n?(S=j[s],R=G.matcher(S),I=R.find()):I=0<=JS.SV.sValue(H.get(s)).indexOf(g);if(k&&I||!k&&I==!h)y++,v.set(s),k&&b.addLast(h?S.substring(0,R.start())+S.substring(R.end()):R.group())}if(!c)return k?
-d.addXStr(1==b.size()?b.get(0):""):h?d.addXBool(1==y):k?d.addXStr(0==y?"":R.group()):d.addXInt(0==y?0:R.start()+1);if(k){c=Array(y);if(0<y)for(s=j.length;0<=--s;)v.get(s)&&(--y,c[y]=k?b.get(y):j[s]);return d.addXAS(c)}c=new JU.Lst;for(s=v.nextSetBit(0);0<=s;s=v.nextSetBit(s+1))c.addLast(H.get(s));return d.addXList(c)}return j?d.addXStr(this.vwr.getJBR().toStdAmino3(JS.SV.sValue(b))):d.addXInt(JS.SV.sValue(b).indexOf(g)+1)},"JS.ScriptMathProcessor,~A");q(c$,"evaluateGetProperty",function(d,a,b,c){var e=
-a.length,f=c&&1275082245==b,h=c&&1275068725==b,g=1275068446==b,k=0,j=0==e?0:a[0].tok;if(2==e&&(7==j||6==j||14==j))return d.addXObj(this.vwr.extractProperty(a[0].value,a[1].value.toString(),-1));var l=c&&1==e&&10==a[0].tok?a[0].value:null,r=null==l&&0<e?JS.SV.sValue(a[k++]):"",j=r,m=j.toLowerCase();!f&&0>m.indexOf("[select ")&&(j=m);var t=!1;j.equals("json")&&e>k&&(t=!0,j=JS.SV.sValue(a[k++]));var n=null;if(c){n=d.getX();switch(n.tok){case 10:break;case 4:var p=n.value,e=Array(3);p.startsWith("$")?
-(p=p.substring(1),a=this.vwr.shm.getShapeIdFromObjectName(p),0<=a&&(e[0]=p,this.vwr.shm.getShapePropertyData(a,"index",e),null!=e[1]&&!r.equals("index")&&(p=e[1].intValue(),e[1]=this.vwr.shm.getShapePropertyIndex(a,r.intern(),p)))):(a=JV.JC.shapeTokenIndex(JS.T.getTokFromName(p)),0<=a&&(e[0]=r,e[1]=Integer.$valueOf(-1),this.vwr.shm.getShapePropertyData(a,r.intern(),e)));return null==e[1]?d.addXStr(""):d.addXObj(e[1]);case 7:if(h){g=n.getList();if(0==e)return d.addXObj(this.getMinMax(g,1275068725,
-!0));c=new java.util.Hashtable;j=1<e?JS.SV.sValue(a[e-1]):null;null!=j&&e--;m=Array(e);for(p=0;p<e;p++)m[p]=JS.SV.sValue(a[p]);p=0;for(t=g.size();p<t;p++)if(k=g.get(p),6==k.tok){r=k.getMap();a="";for(n=0;n<e;n++)l=r.get(m[n]),a+=(0==n?"":j)+JS.SV.sValue(l);r=c.get(a);null==r&&c.put(a,r=JS.SV.newV(7,new JU.Lst));r.getList().addLast(k)}return d.addXMap(c)}if(null!=l){e=n.getList();a=new JU.Lst;for(p=l.nextSetBit(0);0<=p;p=l.nextSetBit(p+1))a.addLast(e.get(p));return d.addXList(a)}default:if(1275068725==
-b&&6==n.tok){c=new java.util.Hashtable;for(e=n.getMap().entrySet().iterator();e.hasNext()&&((p=e.next())||1);)a=p.getKey(),k=p.getValue().asString(),g=c.get(k),null==g&&c.put(k,g=new JU.Lst),g.addLast(a);if("count".equals(m))for(e=c.entrySet().iterator();e.hasNext()&&((p=e.next())||1);)p.setValue(Integer.$valueOf(p.getValue().size()));return d.addXMap(c)}f&&(j="[SELECT "+j+"]");return d.addXObj(this.vwr.extractProperty(n,j,-1))}!m.startsWith("bondinfo")&&(!m.startsWith("atominfo")&&!m.startsWith("modelkitinfo"))&&
-(j="atomInfo."+j)}p="";if(j.equalsIgnoreCase("fileContents")&&2<=e){k=JS.SV.sValue(a[1]);for(p=2;p<e;p++)k+="|"+JS.SV.sValue(a[p]);p=k;k=e}else if(e>k)switch(a[k].tok){case 10:p=a[k++].value;j.equalsIgnoreCase("bondInfo")&&(e>k&&10==a[k].tok)&&(p=C(-1,[p,a[k].value]));break;case 6:case 4:this.vwr.checkPropertyParameter(j)&&(p=a[k++].value)}if(c&&(p=n.value,0>p.nextSetBit(0)))return d.addXStr("");g&&!c&&(j="auxiliaryInfo.models."+j);j=JU.PT.rep(j,".[","[");p=this.vwr.getProperty(null,j,p);k<e&&(p=
-this.vwr.extractProperty(p,a,k));return d.addXObj(t?JS.SV.safeJSON("value",p):JS.SV.isVariableType(p)?p:JU.Escape.toReadable(j,p))},"JS.ScriptMathProcessor,~A,~N,~B");q(c$,"evaluateFormat",function(d,a,b,c){var e=2>b.length||1287653388==a?d.getX():null,f=0==b.length?"%U":7==b[0].tok?null:JS.SV.sValue(b[0]);if(!c&&0<b.length&&null!=e&&10!=e.tok&&null!=f){if(2==b.length){var e=e.getList(),h=b[1].getList();if(null==e||null==h)return!1;e=JS.SV.getVariableList(this.getSublist(e,h))}b=C(-1,[b[0],e]);e=
-null}if(null==e){if(null==f)return!1;a=c?-1:JS.SV.getFormatType(f);if(0<=a&&2!=b.length)return!1;if(0<=a||2>b.length||7!=b[1].tok)return b=JS.SV.format(b,a),f.equalsIgnoreCase("json")?d.addXStr(b):d.addXObj(b);f=b[1].getList();b=C(-1,[b[0],null]);c=Array(f.size());for(e=c.length;0<=--e;)b[1]=f.get(e),c[e]=JS.SV.format(b,a).toString();return d.addXAS(c)}if(7==e.tok&&null==f)return e=e.getList(),h=b[0].getList(),f=this.getSublist(e,h),d.addXList(f);b=10==e.tok?e.value:null;a=JS.T.tokAttr(a,480);return d.addXObj(null==
-f?"":null==b?JS.SV.sprintf(JU.PT.formatCheck(f),e):this.e.getCmdExt().getBitsetIdent(b,f,e.value,!0,e.index,a))},"JS.ScriptMathProcessor,~N,~A,~B");q(c$,"getSublist",function(d,a){for(var b=new JU.Lst,c,e,f,h=0,g=d.size();h<g;h++)switch(e=d.get(h),e.tok){case 6:c=e.getMap();f=new JU.Lst;for(var k=0,j=a.size();k<j;k++)e=c.get(JS.SV.sValue(a.get(k))),f.addLast(null==e?JS.SV.newS(""):e);b.addLast(JS.SV.getVariableList(f));break;case 7:c=new java.util.Hashtable;f=e.getList();k=0;for(j=Math.min(f.size(),
-a.size());k<j;k++)c.put(JS.SV.sValue(a.get(k)),f.get(k));b.addLast(JS.SV.getVariable(c))}return b},"JU.Lst,JU.Lst");q(c$,"evaluateList",function(d,a,b){var c=b.length,e=d.getX(),f=7==e.tok,h;switch(a){case 1275335685:return 2==c&&d.addX(e.pushPop(b[0],b[1]))||1==c&&d.addX(e.pushPop(null,b[0]));case 1275334681:return 1==c&&d.addX(e.pushPop(b[0],null))||0==c&&d.addX(e.pushPop(null,null));case 1275069441:if(1!=c&&2!=c)return!1;break;case 1275069447:case 1275069446:break;default:if(1!=c)return!1}var g=
-null,k=null,j=null;if(2==c){var l=JS.SV.sValue(b[0]);h=b[1];if(1275069441==a){g=f?JS.SV.strListValue(e):JU.PT.split(JS.SV.sValue(e),"\n");k=7==h.tok?JS.SV.strListValue(h):JU.PT.split(JS.SV.sValue(h),"\n");j=Array(c=Math.max(g.length,k.length));for(e=0;e<c;e++)j[e]=(e>=g.length?"":g[e])+l+(e>=k.length?"":k[e]);return d.addXAS(j)}if(1073742335!=h.tok)return!1;j=e.getList();(c=0==l.length)&&(l=",");if(1275069446==a){k=Array(j.size());for(e=j.size();0<=--e;)if(b=j.get(e).getList(),null==b)k[e]=j.get(e);
-else{a=new JU.SB;f=0;for(g=b.size();f<g;f++)0<f&&a.append(l),h=b.get(f),a.append(c&&4==h.tok?'"'+JU.PT.rep(h.value,'"','""')+'"':""+h.asString());k[e]=JS.SV.newS(a.toString())}return d.addXAV(k)}a=new JU.Lst;c&&(l="\x00");k=O(2,0);e=0;for(h=j.size();e<h;e++){f=j.get(e).asString();if(c){k[1]=0;for(g=k[0]=0;;){b=JU.PT.getCSVString(f,k);if(null==b){if(-1==k[1]){f+=++e<h?"\n"+j.get(e).asString():'"';k[1]=g;continue}f=f.substring(0,g)+f.substring(g).$replace(",","\x00");break}f=f.substring(0,g)+f.substring(g,
-k[0]).$replace(",","\x00")+b+f.substring(k[1]);k[1]=g=k[0]+b.length}}for(var r=f.$plit(l),m=new JU.Lst,f=0,g=r.length;f<g;f++){b=r[f];if(0>b.indexOf("."))try{m.addLast(JS.SV.newI(Integer.parseInt(b)));continue}catch(t){if(!L(t,Exception))throw t;}else try{m.addLast(JS.SV.getVariable(Float.$valueOf(Float.parseFloat(b))));continue}catch(n){if(!L(n,Exception))throw n;}m.addLast(JS.SV.newS(b))}a.addLast(JS.SV.getVariableList(m))}return d.addXObj(JS.SV.getVariableList(a))}h=0==c?JS.SV.newV(1073742327,
+g.equalsIgnoreCase("SMILES"))return d.addXStr(this.vwr.getInchi(null,b.value,"SMILES"+m));n=!0;break;case 2:k||r?n=!0:b.value.startsWith("InChI=")?g.equals("SMARTS")?p=this.vwr.getInchi(null,b.value,"SMILES"):n=!0:3>=m.length&&0==m.$replace("m"," ").$replace("i"," ").$replace("v"," ").trim().length&&(n=!0)}var q=!n&&g.equalsIgnoreCase("SMILES"),u=!n&&g.equalsIgnoreCase("SMARTS"),z=!c&&!n&&g.equalsIgnoreCase("CHEMICAL"),x=!c&&!n&&g.equalsIgnoreCase("MF"),A=!c&&!n&&g.equalsIgnoreCase("CELLFORMULA"),
+B=e&&!c&&g.equalsIgnoreCase("INCHI"),D=e&&!c&&g.equalsIgnoreCase("INCHIKEY"),w=!q&&!u&&10==h&&0<=m.toLowerCase().indexOf("map"),n=!q&&!u&&(10==b.tok||8==b.tok||7==b.tok)&&g.toLowerCase().startsWith("equivalent");try{if(n)switch(b.tok){case 10:return d.addXBs(this.vwr.ms.getSymmetryEquivAtoms(b.value));case 8:return d.addXList(this.vwr.getSymmetryEquivPoints(b.value,g+m));case 7:for(var F=new JU.Lst,V=b.getList(),s=0,y=V.size();s<y;s++){var P=JS.SV.ptValue(V.get(s));if(null==P)return!1;F.addLast(P)}return d.addXList(this.vwr.getSymmetryEquivPointList(F,
+g+m))}else if(B||D)return D&&(m+=" key"),d.addXStr(this.vwr.getInchi(JS.SV.getBitSet(b,!0),null,m));if(z){var E=e?b.value:null,K=null==E?JS.SV.sValue(b):this.vwr.getOpenSmiles(E),K=(0==K.length?"":this.vwr.getChemicalInfo(K,m.toLowerCase(),E)).trim();K.startsWith("InChI")&&(K=JU.PT.rep(JU.PT.rep(K,"InChI=",""),"InChIKey=",""));return d.addXStr(K)}if(q||u||e){var e=w?0:q||u?2:1,G=e<a.length&&10==a[e].tok?a[e++].value:null,U="bonds".equalsIgnoreCase(JS.SV.sValue(l)),F=U||r,e=null;switch(b.tok){case 7:case 4:null==
+p&&!c&&(p=JS.SV.sValue(b));if((q||u)&&1==a.length||null!=G)return!1;if(m.equalsIgnoreCase("mf"))e=this.vwr.getSmilesMatcher().getMolecularFormula(p,u,r);else{var G=m,v=!0,s=!1;switch(a.length){case 4:v=JS.SV.bValue(a[3]);case 3:s=JS.SV.bValue(a[2])}var Q=G.equals("chirality"),y=!s&&(!v||!u&&!Q);try{if(e=this.e.getSmilesExt().getSmilesMatches(G,c?JS.SV.strListValue(b):p,null,null,u?2:1,!s,!v),c)return d.addXObj(e)}catch(W){if(L(W,Exception))return System.out.println(W.getMessage()),d.addXInt(-1);throw W;
+}var M=Q?1:(JU.AU.isAI(e),e.length);0==M&&("MF_FAILED"!==this.vwr.getSmilesMatcher().getLastException()&&0>p.toLowerCase().indexOf("noaromatic")&&0>p.toLowerCase().indexOf("strict"))&&(e=this.e.getSmilesExt().getSmilesMatches(G,p,null,null,16|(u?2:1),!s,!v));if(y)return d.addXInt(!v&&0<M?1:M)}break;case 10:v=b.value;if(g.equalsIgnoreCase("spacegroup"))return d.addXObj(this.vwr.findSpaceGroup(v,null,null,!1,!1));if(g.equalsIgnoreCase("crystalClass"))return y=v.nextSetBit(0),v=null,2!=a.length&&(v=
+new JU.BS,v.set(y)),d.addXList(this.vwr.ms.generateCrystalClass(y,null!=v?this.vwr.ms.getAtomSetCenter(v):10==l.tok?this.vwr.ms.getAtomSetCenter(l.value):JS.SV.ptValue(l)));if(x&&0!=m.length)return d.addXBs(JU.JmolMolecule.getBitSetForMF(this.vwr.ms.at,v,m));if(x||A)return d.addXStr(this.vwr.getFormulaForAtoms(v,x?"MF":"CELLFORMULA",r));if(j||t){var Y=l.asString().equalsIgnoreCase("H"),F=(new Boolean(F|Y)).valueOf();return d.addXStr(this.vwr.getSmilesOpt(v,-1,-1,(F?7340032|(Y?9437184:0):0)|(t?34603008:
+1048576),null))}if(w){var H=null,M=Q=y=null,N=3==a.length?JS.SV.sValue(l):null,R=null==N||N.equals("%i")||N.equals("number")?"i":N.equals("%a")||N.equals("name")?"a":N.equals("%D")||N.equals("index")?"D":"?";null==N&&(N="number");l=null;m=m.$replace("map","").trim();g=this.vwr.getSmilesOpt(v,0,0,0,m);if(v.cardinality()!=G.cardinality())l="atom sets are not the same size";else try{0<m.length&&(g="/"+m+"/"+g);var y=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,v,137)[0],
+X=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,G,137);if(0<X.length){H=O(v.length(),0);for(s=H.length;0<=--s;)H[s]=-1;Q=X[0];for(s=y.length;0<=--s;)H[y[s]]=Q[s];var M=C(y.length,2,null),ca=JU.BS.copy(v);ca.or(G);var S="?"==R?Array(ca.length()):null;null!=S&&(S=this.e.getCmdExt().getBitsetIdentFull(ca,N,null,!1,2147483647,!1,S));for(var I=this.vwr.ms.at,X=0,s=v.nextSetBit(0);0<=s;s=v.nextSetBit(s+1)){var aa=H[s];if(-1!=aa){var ba;switch(R){case "a":ba=C(-1,[I[s].getAtomName(),
+I[aa].getAtomName()]);break;case "i":ba=C(-1,[Integer.$valueOf(I[s].getAtomNumber()),Integer.$valueOf(I[aa].getAtomNumber())]);break;case "D":ba=C(-1,[Integer.$valueOf(s),Integer.$valueOf(aa)]);break;default:ba=C(-1,[S[s],S[aa]])}M[X++]=ba}}}}catch(da){if(L(da,Exception))l=da.getMessage();else throw da;}var T=new java.util.HashMap;T.put("BS1",v);T.put("BS2",G);T.put("SMILES",g);null==l?(T.put("SMILEStoBS1",y),T.put("SMILEStoBS2",Q),T.put("BS1toBS2",H),T.put("MAP1to2",M),T.put("key",N)):T.put("error",
+l);return d.addXMap(T)}if(q||u)g=1<a.length&&10==a[1].tok?this.vwr.getSmilesOpt(a[1].value,0,0,0,m):m;m=m.toUpperCase();if(0<=m.indexOf("INCHI"))return d.addXStr(this.vwr.getInchi(v,null,"SMILES/"+m));if(m.equals("MF"))p=this.e.getSmilesExt().getSmilesMatches("",null,v,G,1,!0,!1),e=this.vwr.getSmilesMatcher().getMolecularFormula(p,!1,r);else if(U)H=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,v,(q?1:2)|8),e=0<H.length?this.vwr.ms.getDihedralMap(H[0]):O(0,0);else if(m.equals("MAP"))e=
+H=this.vwr.getSmilesMatcher().getCorrelationMaps(g,this.vwr.ms.at,this.vwr.ms.ac,v,(q?1:2)|144);else{var Z=(q?0<=m.indexOf("OPEN")?5:1:2)|(r&&0==g.length?22020096:0);if(0<=m.indexOf("/MOLECULE/")){for(var ea=this.vwr.ms.getMolecules(),$=new JU.Lst,s=0;s<ea.length;s++)if(ea[s].atomList.intersects(v)){var ha=this.e.getSmilesExt().getSmilesMatches(g,null,ea[s].atomList,G,Z,!r,!1);ha.isEmpty()||$.addLast(ha)}e=$}else e=this.e.getSmilesExt().getSmilesMatches(g,null,v,G,Z,!r,!1)}}null==e&&this.e.invArg();
+return d.addXObj(e)}}catch(fa){if(L(fa,Exception))this.e.evalError(fa.getMessage(),null);else throw fa;}v=new JU.BS;H=c?b.getList():null;if(c&&4!=h&&0!=h){b=a[0];s=0;for(y=H.size();s<y;s++)JS.SV.areEqual(H.get(s),b)&&v.set(s);e=O(v.cardinality(),0);X=0;for(s=v.nextSetBit(0);0<=s;s=v.nextSetBit(s+1))e[X++]=s+1;return d.addXAI(e)}h=0<=m.indexOf("v");s=0<=m.indexOf("i")||k;k=0<=m.indexOf("m");m=0==g.length;n=!m&&!n&&2==a.length;if(c||n){j=n?this.getPatternMatcher():null;G=null;if(n)try{G=j.compile(g,
+s)}catch(ga){if(L(ga,Exception))this.e.evalError(ga.toString(),null);else throw ga;}j=m?null:JS.SV.strListValue(b);N=m?H.size():j.length;JU.Logger.debugging&&JU.Logger.debug("finding "+g);y=0;R=null;b=k?new JU.Lst:null;S="";for(s=0;s<N;s++){if(m)switch(I=H.get(s),I.tok){case 6:I=I.getMap().isEmpty()!=f;break;case 7:I=0==I.getList().size()!=f;break;case 4:I=0==I.asString().length!=f;break;default:I=!0}else n?(S=j[s],R=G.matcher(S),I=R.find()):I=0<=JS.SV.sValue(H.get(s)).indexOf(g);if(k&&I||!k&&I==
+!h)y++,v.set(s),k&&b.addLast(h?S.substring(0,R.start())+S.substring(R.end()):R.group())}if(!c)return k?d.addXStr(1==b.size()?b.get(0):""):h?d.addXBool(1==y):k?d.addXStr(0==y?"":R.group()):d.addXInt(0==y?0:R.start()+1);if(k){c=Array(y);if(0<y)for(s=j.length;0<=--s;)v.get(s)&&(--y,c[y]=k?b.get(y):j[s]);return d.addXAS(c)}c=new JU.Lst;for(s=v.nextSetBit(0);0<=s;s=v.nextSetBit(s+1))c.addLast(H.get(s));return d.addXList(c)}return j?d.addXStr(this.vwr.getJBR().toStdAmino3(JS.SV.sValue(b))):d.addXInt(JS.SV.sValue(b).indexOf(g)+
+1)},"JS.ScriptMathProcessor,~A");q(c$,"evaluateGetProperty",function(d,a,b,c){var e=a.length,f=c&&1275082245==b,h=c&&1275068725==b,g=1275068446==b,k=0,j=0==e?0:a[0].tok;if(2==e&&(7==j||6==j||14==j))return d.addXObj(this.vwr.extractProperty(a[0].value,a[1].value.toString(),-1));var l=c&&1==e&&10==a[0].tok?a[0].value:null,r=null==l&&0<e?JS.SV.sValue(a[k++]):"",j=r,m=j.toLowerCase();!f&&0>m.indexOf("[select ")&&(j=m);var t=!1;j.equals("json")&&e>k&&(t=!0,j=JS.SV.sValue(a[k++]));var n=null;if(c){n=d.getX();
+switch(n.tok){case 10:break;case 4:var p=n.value,e=Array(3);p.startsWith("$")?(p=p.substring(1),a=this.vwr.shm.getShapeIdFromObjectName(p),0<=a&&(e[0]=p,this.vwr.shm.getShapePropertyData(a,"index",e),null!=e[1]&&!r.equals("index")&&(p=e[1].intValue(),e[1]=this.vwr.shm.getShapePropertyIndex(a,r.intern(),p)))):(a=JV.JC.shapeTokenIndex(JS.T.getTokFromName(p)),0<=a&&(e[0]=r,e[1]=Integer.$valueOf(-1),this.vwr.shm.getShapePropertyData(a,r.intern(),e)));return null==e[1]?d.addXStr(""):d.addXObj(e[1]);case 7:if(h){g=
+n.getList();if(0==e)return d.addXObj(this.getMinMax(g,1275068725,!0));c=new java.util.Hashtable;j=1<e?JS.SV.sValue(a[e-1]):null;null!=j&&e--;m=Array(e);for(p=0;p<e;p++)m[p]=JS.SV.sValue(a[p]);p=0;for(t=g.size();p<t;p++)if(k=g.get(p),6==k.tok){r=k.getMap();a="";for(n=0;n<e;n++)l=r.get(m[n]),a+=(0==n?"":j)+JS.SV.sValue(l);r=c.get(a);null==r&&c.put(a,r=JS.SV.newV(7,new JU.Lst));r.getList().addLast(k)}return d.addXMap(c)}if(null!=l){e=n.getList();a=new JU.Lst;for(p=l.nextSetBit(0);0<=p;p=l.nextSetBit(p+
+1))a.addLast(e.get(p));return d.addXList(a)}default:if(1275068725==b&&6==n.tok){c=new java.util.Hashtable;for(e=n.getMap().entrySet().iterator();e.hasNext()&&((p=e.next())||1);)a=p.getKey(),k=p.getValue().asString(),g=c.get(k),null==g&&c.put(k,g=new JU.Lst),g.addLast(a);if("count".equals(m))for(e=c.entrySet().iterator();e.hasNext()&&((p=e.next())||1);)p.setValue(Integer.$valueOf(p.getValue().size()));return d.addXMap(c)}f&&(j="[SELECT "+j+"]");return d.addXObj(this.vwr.extractProperty(n,j,-1))}!m.startsWith("bondinfo")&&
+(!m.startsWith("atominfo")&&!m.startsWith("modelkitinfo"))&&(j="atomInfo."+j)}p="";if(j.equalsIgnoreCase("fileContents")&&2<=e){k=JS.SV.sValue(a[1]);for(p=2;p<e;p++)k+="|"+JS.SV.sValue(a[p]);p=k;k=e}else if(e>k)switch(a[k].tok){case 10:p=a[k++].value;j.equalsIgnoreCase("bondInfo")&&(e>k&&10==a[k].tok)&&(p=C(-1,[p,a[k].value]));break;case 6:case 4:this.vwr.checkPropertyParameter(j)&&(p=a[k++].value)}if(c&&(p=n.value,0>p.nextSetBit(0)))return d.addXStr("");g&&!c&&(j="auxiliaryInfo.models."+j);j=JU.PT.rep(j,
+".[","[");p=this.vwr.getProperty(null,j,p);k<e&&(p=this.vwr.extractProperty(p,a,k));return d.addXObj(t?JS.SV.safeJSON("value",p):JS.SV.isVariableType(p)?p:JU.Escape.toReadable(j,p))},"JS.ScriptMathProcessor,~A,~N,~B");q(c$,"evaluateFormat",function(d,a,b,c){var e=2>b.length||1287653388==a?d.getX():null,f=0==b.length?"%U":7==b[0].tok?null:JS.SV.sValue(b[0]);if(!c&&0<b.length&&null!=e&&10!=e.tok&&null!=f){if(2==b.length){var e=e.getList(),h=b[1].getList();if(null==e||null==h)return!1;e=JS.SV.getVariableList(this.getSublist(e,
+h))}b=C(-1,[b[0],e]);e=null}if(null==e){if(null==f)return!1;a=c?-1:JS.SV.getFormatType(f);if(0<=a&&2!=b.length)return!1;if(0<=a||2>b.length||7!=b[1].tok)return b=JS.SV.format(b,a),f.equalsIgnoreCase("json")?d.addXStr(b):d.addXObj(b);f=b[1].getList();b=C(-1,[b[0],null]);c=Array(f.size());for(e=c.length;0<=--e;)b[1]=f.get(e),c[e]=JS.SV.format(b,a).toString();return d.addXAS(c)}if(7==e.tok&&null==f)return e=e.getList(),h=b[0].getList(),f=this.getSublist(e,h),d.addXList(f);b=10==e.tok?e.value:null;a=
+JS.T.tokAttr(a,480);return d.addXObj(null==f?"":null==b?JS.SV.sprintf(JU.PT.formatCheck(f),e):this.e.getCmdExt().getBitsetIdent(b,f,e.value,!0,e.index,a))},"JS.ScriptMathProcessor,~N,~A,~B");q(c$,"getSublist",function(d,a){for(var b=new JU.Lst,c,e,f,h=0,g=d.size();h<g;h++)switch(e=d.get(h),e.tok){case 6:c=e.getMap();f=new JU.Lst;for(var k=0,j=a.size();k<j;k++)e=c.get(JS.SV.sValue(a.get(k))),f.addLast(null==e?JS.SV.newS(""):e);b.addLast(JS.SV.getVariableList(f));break;case 7:c=new java.util.Hashtable;
+f=e.getList();k=0;for(j=Math.min(f.size(),a.size());k<j;k++)c.put(JS.SV.sValue(a.get(k)),f.get(k));b.addLast(JS.SV.getVariable(c))}return b},"JU.Lst,JU.Lst");q(c$,"evaluateList",function(d,a,b){var c=b.length,e=d.getX(),f=7==e.tok,h;switch(a){case 1275335685:return 2==c&&d.addX(e.pushPop(b[0],b[1]))||1==c&&d.addX(e.pushPop(null,b[0]));case 1275334681:return 1==c&&d.addX(e.pushPop(b[0],null))||0==c&&d.addX(e.pushPop(null,null));case 1275069441:if(1!=c&&2!=c)return!1;break;case 1275069447:case 1275069446:break;
+default:if(1!=c)return!1}var g=null,k=null,j=null;if(2==c){var l=JS.SV.sValue(b[0]);h=b[1];if(1275069441==a){g=f?JS.SV.strListValue(e):JU.PT.split(JS.SV.sValue(e),"\n");k=7==h.tok?JS.SV.strListValue(h):JU.PT.split(JS.SV.sValue(h),"\n");j=Array(c=Math.max(g.length,k.length));for(e=0;e<c;e++)j[e]=(e>=g.length?"":g[e])+l+(e>=k.length?"":k[e]);return d.addXAS(j)}if(1073742335!=h.tok)return!1;j=e.getList();(c=0==l.length)&&(l=",");if(1275069446==a){k=Array(j.size());for(e=j.size();0<=--e;)if(b=j.get(e).getList(),
+null==b)k[e]=j.get(e);else{a=new JU.SB;f=0;for(g=b.size();f<g;f++)0<f&&a.append(l),h=b.get(f),a.append(c&&4==h.tok?'"'+JU.PT.rep(h.value,'"','""')+'"':""+h.asString());k[e]=JS.SV.newS(a.toString())}return d.addXAV(k)}a=new JU.Lst;c&&(l="\x00");k=O(2,0);e=0;for(h=j.size();e<h;e++){f=j.get(e).asString();if(c){k[1]=0;for(g=k[0]=0;;){b=JU.PT.getCSVString(f,k);if(null==b){if(-1==k[1]){f+=++e<h?"\n"+j.get(e).asString():'"';k[1]=g;continue}f=f.substring(0,g)+f.substring(g).$replace(",","\x00");break}f=f.substring(0,
+g)+f.substring(g,k[0]).$replace(",","\x00")+b+f.substring(k[1]);k[1]=g=k[0]+b.length}}for(var r=f.$plit(l),m=new JU.Lst,f=0,g=r.length;f<g;f++){b=r[f];if(0>b.indexOf("."))try{m.addLast(JS.SV.newI(Integer.parseInt(b)));continue}catch(t){if(!L(t,Exception))throw t;}else try{m.addLast(JS.SV.getVariable(Float.$valueOf(Float.parseFloat(b))));continue}catch(n){if(!L(n,Exception))throw n;}m.addLast(JS.SV.newS(b))}a.addLast(JS.SV.getVariableList(m))}return d.addXObj(JS.SV.getVariableList(a))}h=0==c?JS.SV.newV(1073742327,
 "all"):b[0];j=1073742327==h.tok;if(!f&&4!=e.tok)return d.binaryOp(this.opTokenFor(a),e,h);var r=JS.SV.isScalar(e),p=JS.SV.isScalar(h),q=m=null,l=e.getList(),u=h.getList();f?c=l.size():r?c=2147483647:(g=JU.PT.split(JS.SV.sValue(e),"\n"),m=x(c=g.length,0),JU.PT.parseFloatArrayData(g,m));if(j&&1275069446!=a){j=0;if(f)for(e=c;0<=--e;)j+=JS.SV.fValue(l.get(e));else if(!r)for(e=c;0<=--e;)j+=m[e];return d.addXFloat(j)}if(1275069446==a&&4==h.tok){a=new JU.SB;if(r)a.append(JS.SV.sValue(e));else{b=j?"":h.value.toString();
 for(e=0;e<c;e++)a.append(0<e?b:"").append(JS.SV.sValue(l.get(e)))}return d.addXStr(a.toString())}var z=null;p?z=h:7==h.tok?c=Math.min(c,u.size()):(k=JU.PT.split(JS.SV.sValue(h),"\n"),q=x(k.length,0),JU.PT.parseFloatArrayData(k,q),c=Math.min(c,q.length));var C=this.opTokenFor(a);if(f&&j)return j=new JU.Lst,d.addXList(this.addAllLists(e.getList(),j));b=r?e:null;var A,B=2147483647==c;B&&(c=1);for(var D=Array(c),e=0;e<c;e++){A=p?z:7==h.tok?u.get(e):Float.isNaN(q[e])?JS.SV.getVariable(JS.SV.unescapePointOrBitsetAsVariable(k[e])):
 JS.SV.newF(q[e]);r||(b=f?l.get(e):Float.isNaN(m[e])?JS.SV.getVariable(JS.SV.unescapePointOrBitsetAsVariable(g[e])):JS.SV.newF(m[e]));1275069446==a&&7!=b.tok&&(j=new JU.Lst,j.addLast(b),b=JS.SV.getVariableList(j));if(!d.binaryOp(C,b,A))return!1;D[e]=d.getX()}return B?d.addXObj(D[0]):d.addXAV(D)},"JS.ScriptMathProcessor,~N,~A");q(c$,"addAllLists",function(d,a){for(var b=d.size(),c=0;c<b;c++){var e=d.get(c);7==e.tok?this.addAllLists(e.getList(),a):a.addLast(e)}return a},"JU.Lst,JU.Lst");q(c$,"evaluateLoad",
